@@ -233,9 +233,9 @@ def preset_menu(preset_id):
     row.eb.connect("button-press-event", set_up_dock_tab, preset, preset_name)
     list_box.add(row)
 
-    row = SideMenuRow(voc["exit-menu"], margin_start=18)
-    row.eb.connect("button-press-event", set_up_bar_tab, preset, preset_name)
-    list_box.add(row)
+    # row = SideMenuRow(voc["exit-menu"], margin_start=18)
+    # row.eb.connect("button-press-event", set_up_bar_tab, preset, preset_name)
+    # list_box.add(row)
 
     row = SideMenuRow(voc["notifications"], margin_start=18)
     row.eb.connect("button-press-event", set_up_notification_tab, preset, preset_name)
@@ -363,12 +363,12 @@ def set_up_dock_tab(event_box, event_button, preset, preset_name):
     grid.attach(content, 1, 0, 1, 1)
 
 
-def set_up_bar_tab(event_box, event_button, preset, preset_name):
-    hide_submenus()
-    global content
-    content.destroy()
-    content = bar_tab(preset, preset_name, voc)
-    grid.attach(content, 1, 0, 1, 1)
+# def set_up_bar_tab(event_box, event_button, preset, preset_name):
+#     hide_submenus()
+#     global content
+#     content.destroy()
+#     content = bar_tab(preset, preset_name, voc)
+#     grid.attach(content, 1, 0, 1, 1)
 
 
 def set_up_notification_tab(event_box, event_button, preset, preset_name):
@@ -678,6 +678,9 @@ def save_includes():
     if preset["dock-exclusive"]:
         cmd_dock += " -x"
 
+    if preset["launcher-at-start"]:
+        cmd_dock += " -lp start"
+
     if "preset-" in settings["panel-preset"]:
         cmd_dock += " -s {}.css".format(settings["panel-preset"])
     elif preset["dock-css"]:
@@ -820,6 +823,7 @@ def save_includes():
         lines.append('  natural_scroll {}'.format(settings["touchpad-natural-scroll"]))
         lines.append('  scroll_factor {}'.format(settings["touchpad-scroll-factor"]))
         lines.append('  scroll_method {}'.format(settings["touchpad-scroll-method"]))
+        lines.append('  click_method {}'.format(settings["touchpad-click-method"]))
         lines.append('  left_handed {}'.format(settings["touchpad-left-handed"]))
         lines.append('  tap {}'.format(settings["touchpad-tap"]))
         lines.append('  tap_button_map {}'.format(settings["touchpad-tap-button-map"]))
@@ -929,6 +933,7 @@ def load_settings():
         "touchpad-drag-lock": "disabled",
         "touchpad-dwt": "enabled",
         "touchpad-middle-emulation": "enabled",
+        "touchpad-click-method": "button_areas",
         "touchpad-custom-name": "",
         "touchpad-custom-value": "",
         "lockscreen-use-settings": True,
@@ -948,6 +953,10 @@ def load_settings():
         "unsplash-width": 1920,
         "unsplash-height": 1080,
         "unsplash-keywords": ["nature", "water", "landscape"],
+        "wallhaven-ratio": "16x9,16x10",
+        "wallhaven-atleast": "1920x1080",
+        "wallhaven-api-key": "",
+        "wallhaven-tags": ["nature", "landscape"],
         "help-font-size": 12,
         "help-layer-shell": True,
         "help-keyboard": False,
@@ -1000,6 +1009,7 @@ def load_presets():
 def load_preset(file_name):
     defaults = {
         "panel-css": "",
+        "launcher-at-start": False,
         "launcher-columns": 6,
         "launcher-icon-size": 64,
         "launcher-file-search-columns": 2,
